@@ -1,10 +1,13 @@
+from . import action_controllers
+from . import main
+from . import version
 from .action_controllers import *
 from .common import *
 from .extend import *
 from .version import *
+from .main_controllers import *
 from .main import *
 from .plugins import *
-from . import controllers
 
 __all__ = action_controllers.__all__ + common.__all__ + version.__all__ + main.__all__ + \
-          plugins.__all__ + extend.__all__
+          plugins.__all__ + main_controllers.__all__ + extend.__all__
